/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.cq.app.internal.WebAppView");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("net.jazz.ajax.ui.PlatformUI");
dojo.require("com.ibm.rational.report.web.cq.app.internal.SideNavigationLayout");
dojo.require("com.ibm.rational.report.web.core.app.internal.WebAppController");
dojo.require("com.ibm.rational.report.web.core.app.internal.MessageFormatter");
dojo.require("com.ibm.rational.report.web.core.app.internal.common.ErrorDialog");
dojo.require("com.ibm.rational.report.web.core.app.view.navigation.ReportNavigator");
dojo.require("com.ibm.rational.report.web.core.app.view.report.NewReportFolderViewer");
dojo.require("com.ibm.rational.report.web.core.app.view.report.NewReportDesignViewer");
dojo.require("com.ibm.rational.report.web.core.app.view.report.AddReportsViewer");
dojo.require("com.ibm.rational.report.web.core.app.view.report.EditReportNodeViewer");
dojo.require("com.ibm.rational.report.web.core.app.view.report.EditReportFolderViewer");
dojo.require("com.ibm.rational.report.web.core.app.view.report.ReportViewer");
dojo.require("com.ibm.rational.report.web.core.app.view.admin.ReportAdminViewer");
dojo.require("com.ibm.rational.report.web.core.app.view.security.GrantPermissionViewer");
dojo.require("com.ibm.rational.report.web.cq.app.view.navigation.AdminNavigator");
dojo.require("com.ibm.rational.report.web.cq.app.view.admin.UserAdminViewer");
dojo.require("com.ibm.rational.report.web.core.app.view.admin.ViewUserViewer");
dojo.require("com.ibm.rational.report.web.cq.app.view.admin.UserCredentialViewer");
dojo.require("com.ibm.team.repository.web.client.session.Session");
dojo.require("com.ibm.rational.report.web.core.client.internal.UserClient");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.view.navigation", "Messages");
dojo.requireLocalization("com.ibm.rational.report.web.cq.app.internal", "Messages");

var ServiceabilityMessages			= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");
var NavigationMessages				= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.view.navigation", "Messages");
var InternalMessages				= dojo.i18n.getLocalization("com.ibm.rational.report.web.cq.app.internal", "Messages");
var UserClient						= com.ibm.rational.report.web.core.client.internal.UserClient;
var MessageFormatter				= com.ibm.rational.report.web.core.app.internal.MessageFormatter;
var session							= com.ibm.team.repository.web.client.session;
var ServiceResponseHandler			= com.ibm.team.repository.web.transport.ServiceResponseHandler;
var PlatformUI						= net.jazz.ajax.ui.PlatformUI;
var ActionRegistry					= null;

/**
 * Main application view.
 */
dojo.declare(
	"com.ibm.rational.report.web.cq.app.internal.WebAppView",
	[dijit._Widget, dijit._Templated], {
	
	templatePath: dojo.moduleUrl("com.ibm.rational.report.web.cq", "app/internal/templates/WebAppView.html"),

	postCreate: function() {
		com.ibm.rational.report.web.cq.app.internal.WebAppView.superclass.postCreate.apply(this);
		
		this._msgFormatter = new MessageFormatter(null);
		this._controller = this._createController();
		this._mainView = new com.ibm.rational.report.web.cq.app.internal.SideNavigationLayout({}, this._appContainer);
		
		this._controller.prototype = this._mainView._controller;
			
		// lazy initialize ActionRegistry
		ActionRegistry = PlatformUI.getWorkbench().getActionRegistry();
		
		// register the default action
		ActionRegistry.registerAction("com.ibm.rational.report.web.core.defaultAction", this._controller, "defaultAction");
		
		// register actions for listing the available report queries, designs and snapshots
		ActionRegistry.registerAction("com.ibm.rational.report.web.core.getAllReports", this._controller, "getAllReports");
							
		// register actions for viewing the available reports
		ActionRegistry.registerAction("com.ibm.rational.report.web.core.viewReportDesign", this._controller, "viewReportDesign");
		ActionRegistry.registerAction("com.ibm.rational.report.web.core.viewReportQuery", this._controller, "viewReportQuery");
		ActionRegistry.registerAction("com.ibm.rational.report.web.core.viewReportSnapshot", this._controller, "viewReportSnapshot");
		
		// register actions for managing the report designs, queries and snapshots
		ActionRegistry.registerAction("com.ibm.rational.report.web.core.manageReports", this._controller, "manageReports");
		ActionRegistry.registerAction("com.ibm.rational.report.web.core.newReportDesign", this._controller, "newReportDesign");
			
		// register actions for managing users and groups
		ActionRegistry.registerAction("com.ibm.rational.report.web.cq.manageUsers", this._controller, "manageUsers");		
		ActionRegistry.registerAction("com.ibm.rational.report.web.cq.viewUserProfile", this._controller, "editUser");
		
		// register actions for managing permissions
		ActionRegistry.registerAction("com.ibm.rational.report.web.core.grantPermission", this._controller, "grantPermission");
		
		// register actions for managing report categorization
		ActionRegistry.registerAction("com.ibm.rational.report.web.core.newReportFolder", this._controller, "newReportFolder");
		ActionRegistry.registerAction("com.ibm.rational.report.web.core.editReportNode", this._controller, "editReportNode");
		ActionRegistry.registerAction("com.ibm.rational.report.web.core.addReportsToFolder", this._controller, "addReportsToFolder");
					
		var srh = new ServiceResponseHandler(this, "_getIsAdmin", "_getIsAdminError");
		UserClient.getIsAdmin(srh, {name: session.getAuthenticatedContributor().userId});
	},
	
	_getIsAdmin : function(isAdmin) {
		// load the navigation tree data
		this._initializeLeftNavigator(isAdmin);
		this._initializeMainContentArea();
	},
	
	_getIsAdminError: function() {
		// load the navigation tree data
		this._initializeLeftNavigator(false);
		this._initializeMainContentArea();
	},
	
	/**
	 * Creates the application controller.
	 */
	_createController: function() {
		return new com.ibm.rational.report.web.core.app.internal.WebAppController(this);
	},
		
	/**
	 * Framework API for hyperlinks and back/forward.
	 */
	getController: function() {
		return this._controller;
	},
	
	/**
	 * Initializes the left navigation section.
	 */
	_initializeLeftNavigator: function(isAdmin) {
		var args = {controller: this._controller};
		
		this._controller.secMgr._isAdmin = (isAdmin == "true" || isAdmin == true);
		if (!session.isGuest()) {
			if (isAdmin == "true" || isAdmin == true) {
				var widget = new com.ibm.rational.report.web.cq.app.view.navigation.AdminNavigator(args);
				this._adminNavigator = widget;
				this._mainView.addNavigationSection(widget.domNode, NavigationMessages.ADMIN_DRAWER_TITLE);
			}
			
			var widget = new com.ibm.rational.report.web.core.app.view.navigation.ReportNavigator(args);
			this._reportsNavigator = widget;
			
			var self = this;
			var menu = new dijit.Menu();
			var item = new dijit.MenuItem({
				label: NavigationMessages.NEW_REPORT_FOLDER_MENU_ITEM_LABEL,
				iconClass: "newReportFolderIcon",
				onClick: function() {
					self._controller.newReportFolder(null);
				}
			});
			menu.addChild(item);
			menu.domNode.style.display = "none";
			
			this._reportsNavSection = this._mainView.addNavigationSection(widget.domNode, NavigationMessages.REPORTS_DRAWER_TITLE, menu);
			this._controller.initializeSharedReports(widget);
		}
	},
	
	/**
	 * Initializes the main content area.
	 */
	_initializeMainContentArea: function() {
	},
	
	showReport: function(report) {
		var viewer = new com.ibm.rational.report.web.core.app.view.report.ReportViewer({reportItemId: report.id, design: report.design, reportParamNames: report.reportParamNames, reportParamValues: report.reportParamValues, collapseParameters: false, controller: this._controller, type: report.type});
		this._mainView.setMainContent(viewer.domNode);
	},

	manageReports: function() {
		var viewer = new com.ibm.rational.report.web.core.app.view.admin.ReportAdminViewer({controller: this._controller});
		this._mainView.setMainContent(viewer.domNode);			
	},
	
	newReportDesign: function(parentNodeId, postSave, postCancel) {
 		var viewer = new com.ibm.rational.report.web.core.app.view.report.NewReportDesignViewer(
			{controller: this._controller, nodeId: parentNodeId,
			postSave: postSave, postCancel: postCancel,createPermissionsTab: false});
		this._mainView.setMainContent(viewer.domNode);	
		viewer.startup();
	},
	
	manageUsers: function() {
		var viewer = new com.ibm.rational.report.web.cq.app.view.admin.UserAdminViewer({controller: this._controller});
		this._mainView.setMainContent(viewer.domNode);
	},	
	
	editUser: function(userName, viewUserProfile) {
		if(viewUserProfile){
			var viewer = new com.ibm.rational.report.web.cq.app.view.admin.UserCredentialViewer({controller: this._controller, userName: userName});
			this._mainView.setMainContent(viewer.domNode);
		} else {
			var viewer = new com.ibm.rational.report.web.core.app.view.admin.ViewUserViewer({controller: this._controller, userName: userName, viewUserProfile: viewUserProfile});
			this._mainView.setMainContent(viewer.domNode);
		}
	},

	grantPermission: function(resource, principalMap, allPrincipals, aclEntryPrincipals, postSave, postCancel) {
		var viewer = new com.ibm.rational.report.web.core.app.view.security.GrantPermissionViewer(
			{controller: this._controller, resource: resource,
			 principalMap: principalMap, allPrincipals: allPrincipals, aclEntryPrincipals: aclEntryPrincipals, postSave: postSave, postCancel: postCancel});
		this._mainView.setMainContent(viewer.domNode);	
	},
	
	newReportFolder: function(parentNode, postSave, postCancel) {
		var viewer = new com.ibm.rational.report.web.core.app.view.report.NewReportFolderViewer(
			{controller: this._controller, parentNode: parentNode, postSave: postSave, postCancel: postCancel,createPermissionsTab: false});
		this._mainView.setMainContent(viewer.domNode);
		viewer.startup();
	},
	
	editReportNode: function(node, selectedReport, postSave, postCancel) {		
		if (node!= null && node.nodeType == "REPORT_FOLDER") {
			var viewer = new com.ibm.rational.report.web.core.app.view.report.EditReportFolderViewer({
				controller: this._controller,
				node: node,
				postSave: postSave,
				postCancel: postCancel,
				createPermissionsTab: false
			});
			this._mainView.setMainContent(viewer.domNode);
			viewer.startup();
		}
		else {
			var viewer = new com.ibm.rational.report.web.core.app.view.report.EditReportNodeViewer({
				controller: this._controller,
				node: node,
				selectedReport: selectedReport,
				postSave: postSave,
				postCancel: postCancel,
				createPermissionsTab: false
			});
			this._mainView.setMainContent(viewer.domNode);
			viewer.startup();			
		}		
	},
	
	addReportsToFolder: function(nodeId, postSave, postCancel) {
	var viewer = new com.ibm.rational.report.web.core.app.view.report.AddReportsViewer(
			{controller: this._controller, nodeId: nodeId,  
			postSave: postSave, postCancel: postCancel});
		this._mainView.setMainContent(viewer.domNode);
	},
	
	clearMainContent: function() {
		this._mainView.setMainContent(document.createTextNode(""));
	},

	_initializationError: function(error) {
		var errorMsg = this._msgFormatter.formatErrorMessage(ServiceabilityMessages.INTERNAL_APPLICATION_ERROR, error);
		this._displayErrorMessage(errorMsg);
	},
	
	_displayErrorMessage: function(errorMsg) {
		var errorDialog = new com.ibm.rational.report.web.core.app.internal.common.ErrorDialog();
		errorDialog.displayError(errorMsg);
	}
	
});

})();